/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/

#import "DepotExpander.h"
#import <Cocoa/Cocoa.h>
#import "DepotController.h"
#import "PerforceActionWhere.h"

@implementation DepotExpander

+ (void) expandPath:(NSString*)depotPath depot:(DepotController*)depot usep4Where:(BOOL)usep4Where
{
	DepotExpander* expander = [[[DepotExpander alloc] initWithPath:depotPath depot:depot usep4Where:usep4Where] autorelease];
	
	[expander expand];
}

- (void) dealloc
{
	[fDepotPath release];
	[fDepotController release];
	
	[super dealloc];
}

- (id) initWithPath:(NSString*)depotPath depot:(DepotController*)depot usep4Where:(BOOL)usep4Where
{
    self = [super init];

	fUseWhere = usep4Where;
	
	// p4 where does not like it if the path ends in a slash. Remove the trailing
	// slash if it exists
	
	int lastCharIndex = [depotPath length] - 1;
	
	if ( (lastCharIndex >= 0) && ([depotPath characterAtIndex:lastCharIndex] == '/') )
	{
		fDepotPath = [[depotPath substringWithRange:NSMakeRange(0, lastCharIndex)] copy];
	}
	else
	{
		fDepotPath = [depotPath copy];
	}
	
	fDepotController = [depot retain];
		
	return self;
}

- (void) resultFromPerforceWhere: (PerforceActionWhere*) action
{
	if ( [action wasSuccess] )
	{
		[fDepotController expandPath:[action getDepotPath]];
	}
	
	[self autorelease];
}


- (void) expand
{
	if ( fUseWhere )
	{
		[self retain];
		
		[PerforceActionWhere defaultRunFor:self selector:@selector(resultFromPerforceWhere:) withPath:fDepotPath];
	}
	else
	{
		[fDepotController expandPath:fDepotPath];
	}
}

@end
